@@ -1,11 +1,13 @@
 package com.unciv.logic
 
+import com.unciv.Constants
 import com.unciv.logic.city.CityConstructions
-import com.unciv.logic.city.PerpetualConstruction
 import com.unciv.logic.civilization.diplomacy.DiplomacyFlags
 import com.unciv.logic.civilization.diplomacy.DiplomacyManager
 import com.unciv.logic.civilization.managers.TechManager
+import com.unciv.logic.map.tile.RoadStatus
 import com.unciv.models.ruleset.ModOptions
+import com.unciv.models.ruleset.PerpetualConstruction
 import com.unciv.models.ruleset.Ruleset
 
 /**
@@ -35,6 +37,20 @@ object BackwardCompatibility {
             }
         }
 
+        // Mod decided you can't repair things anymore - get rid of old pillaged improvements
+        if (!ruleset.tileImprovements.containsKey(Constants.repair))
+            for (tile in tileMap.values) {
+                if (tile.roadIsPillaged) {
+                    tile.roadStatus = RoadStatus.None
+                    tile.roadIsPillaged = false
+                }
+                if (tile.improvementIsPillaged){
+                    tile.improvement = null
+                    tile.improvementIsPillaged = false
+                }
+            }
+
+
         for (city in civilizations.asSequence().flatMap { it.cities.asSequence() }) {
 
             changeBuildingNameIfNotInRuleset(ruleset, city.cityConstructions, "Hanse", "Bank")
@@ -142,13 +158,8 @@ object BackwardCompatibility {
     /** Move max XP from barbarians to new home */
     @Suppress("DEPRECATION")
     fun ModOptions.updateDeprecations() {
-        if (maxXPfromBarbarians != 30) {
-            constants.maxXPfromBarbarians = maxXPfromBarbarians
-            maxXPfromBarbarians = 30
-        }
     }
 
-
     /** Convert from Fortify X to Fortify and save off X */
     fun GameInfo.convertFortify() {
         val reg = Regex("""^Fortify\s+(\d+)([\w\s]*)""")
@@ -163,23 +174,10 @@ object BackwardCompatibility {
         }
     }
 
-    private fun isOldFormat(manager: BarbarianManager): Boolean {
-        val keys = manager.camps.keys as Set<Any>
-        val iterator = keys.iterator()
-        while (iterator.hasNext()) {
-            val key = iterator.next()
-            if (key is String) {
-                return true
-            }
-        }
-        return false
-    }
-
-    @Suppress("DEPRECATION")
-    fun GameInfo.convertOldGameSpeed() {
-        if (gameParameters.gameSpeed != "" && gameParameters.gameSpeed in ruleset.speeds.keys) {
-            gameParameters.speed = gameParameters.gameSpeed
-            gameParameters.gameSpeed = ""
+    fun GameInfo.convertEncampmentData(){
+        if (barbarians.camps.isNotEmpty()){
+            barbarians.encampments.addAll(barbarians.camps.values)
+            barbarians.camps.clear()
         }
     }
 
