@@ -15,13 +15,17 @@ import com.unciv.utils.Display
 import com.unciv.utils.ScreenOrientation
 import java.text.Collator
 import java.time.Duration
-import java.util.*
+import java.util.Locale
 import kotlin.reflect.KClass
 import kotlin.reflect.KMutableProperty0
 
 data class WindowState (val width: Int = 900, val height: Int = 600)
 
-enum class ScreenSize(val virtualWidth:Float, val virtualHeight:Float){
+enum class ScreenSize(
+    @Suppress("unused")  // Actual width determined by screen aspect ratio, this as comment only
+    val virtualWidth: Float,
+    val virtualHeight: Float
+) {
     Tiny(750f,500f),
     Small(900f,600f),
     Medium(1050f,700f),
@@ -31,11 +35,16 @@ enum class ScreenSize(val virtualWidth:Float, val virtualHeight:Float){
 
 class GameSettings {
 
+    /** Allows panning the map by moving the pointer to the screen edges */
     var mapAutoScroll: Boolean = false
+    /** How fast the map pans using keyboard or with [mapAutoScroll] and mouse */
+    var mapPanningSpeed: Float = 6f
+
     var showWorkedTiles: Boolean = false
     var showResourcesAndImprovements: Boolean = true
     var showTileYields: Boolean = false
     var showUnitMovements: Boolean = false
+    var showSettlersSuggestedCityLocations: Boolean = true
 
     var checkForDueUnits: Boolean = true
     var autoUnitCycle: Boolean = true
@@ -69,7 +78,6 @@ class GameSettings {
     val showPixelUnits: Boolean get() = unitSet != null
     var showPixelImprovements: Boolean = true
     var continuousRendering = false
-    var experimentalRendering = false
     var orderTradeOffersByAmount = true
     var confirmNextTurn = false
     var windowState = WindowState()
@@ -88,7 +96,8 @@ class GameSettings {
 
     var enableEspionageOption = false
 
-    var lastOverviewPage = EmpireOverviewCategories.Cities  // serializes same as the String we had before
+    // This is a string not an enum so if tabs change it won't screw up the json serialization
+    var lastOverviewPage = EmpireOverviewCategories.Cities.name
 
     /** Orientation for mobile platforms */
     var displayOrientation = ScreenOrientation.Landscape
@@ -106,6 +115,12 @@ class GameSettings {
 
     var keyBindings = KeyboardBindings()
 
+    /** NotificationScroll on Word Screen visibility control - mapped to NotificationsScroll.UserSetting enum */
+    var notificationScroll: String = ""
+
+    /** If on, selected notifications are drawn enlarged with wider padding */
+    var enlargeSelectedNotification = true
+
     /** used to migrate from older versions of the settings */
     var version: Int? = null
 
@@ -148,7 +163,7 @@ class GameSettings {
         return (Fonts.ORIGINAL_FONT_SIZE * fontSizeMultiplier).toInt()
     }
 
-    fun getCurrentLocale(): Locale {
+    private fun getCurrentLocale(): Locale {
         if (locale == null)
             updateLocaleFromLanguage()
         return locale!!
@@ -208,15 +223,16 @@ enum class LocaleCode(var language: String, var country: String) {
 class GameSettingsMultiplayer {
     var userId = ""
     var passwords = mutableMapOf<String, String>()
+    @Suppress("unused")  // @GGuenni knows what he intended with this field
     var userName: String = ""
     var server = Constants.uncivXyzServer
     var friendList: MutableList<FriendList.Friend> = mutableListOf()
     var turnCheckerEnabled = true
     var turnCheckerPersistentNotificationEnabled = true
-    var turnCheckerDelay = Duration.ofMinutes(5)
+    var turnCheckerDelay: Duration = Duration.ofMinutes(5)
     var statusButtonInSinglePlayer = false
-    var currentGameRefreshDelay = Duration.ofSeconds(10)
-    var allGameRefreshDelay = Duration.ofMinutes(5)
+    var currentGameRefreshDelay: Duration = Duration.ofSeconds(10)
+    var allGameRefreshDelay: Duration = Duration.ofMinutes(5)
     var currentGameTurnNotificationSound: UncivSound = UncivSound.Silent
     var otherGameTurnNotificationSound: UncivSound = UncivSound.Silent
     var hideDropboxWarning = false
@@ -228,6 +244,7 @@ class GameSettingsMultiplayer {
     }
 }
 
+@Suppress("SuspiciousCallableReferenceInLambda")  // By @Azzurite, safe as long as that warning below is followed
 enum class GameSetting(
     val kClass: KClass<*>,
     private val propertyGetter: (GameSettings) -> KMutableProperty0<*>
