@@ -330,6 +330,38 @@ object UniqueTriggerActivation {
                 return true
             }
 
+            UniqueType.OneTimeProvideResources -> {
+                val amount = unique.params[0].toInt()
+                val resourceName = unique.params[1]
+                val resource = ruleSet.tileResources[resourceName] ?: return false
+                if (!resource.isStockpiled()) return false
+
+                civInfo.resourceStockpiles.add(resourceName, amount)
+
+                val notificationText = getNotificationText(notification, triggerNotificationText,
+                    "You have gained [$amount] [$resourceName]")
+                    ?: return true
+
+                civInfo.addNotification(notificationText, NotificationCategory.General, NotificationIcon.Science, "ResourceIcons/$resourceName")
+                return true
+            }
+
+            UniqueType.OneTimeConsumeResources -> {
+                val amount = unique.params[0].toInt()
+                val resourceName = unique.params[1]
+                val resource = ruleSet.tileResources[resourceName] ?: return false
+                if (!resource.isStockpiled()) return false
+
+                civInfo.resourceStockpiles.add(resourceName, -amount)
+
+                val notificationText = getNotificationText(notification, triggerNotificationText,
+                    "You have lost [$amount] [$resourceName]")
+                    ?: return true
+
+                civInfo.addNotification(notificationText, NotificationCategory.General, NotificationIcon.Science, "ResourceIcons/$resourceName")
+                return true
+            }
+
             UniqueType.OneTimeRevealEntireMap -> {
                 if (notification != null) {
                     civInfo.addNotification(notification, LocationAction(tile?.position), NotificationCategory.General, NotificationIcon.Scout)
@@ -366,6 +398,21 @@ object UniqueTriggerActivation {
                 return promotedUnitLocations.isNotEmpty()
             }
 
+            /**
+             * The mechanics for granting great people are wonky, but basically the following happens:
+             * Based on the game speed, a timer with some amount of turns is set, 40 on regular speed
+             * Every turn, 1 is subtracted from this timer, as long as you have at least 1 city state ally
+             * So no, the number of city-state allies does not matter for this. You have a global timer for all of them combined.
+             * If the timer reaches the amount of city-state allies you have (or 10, whichever is lower), it is reset.
+             * You will then receive a random great person from a random city-state you are allied to
+             * The very first time after acquiring this policy, the timer is set to half of its normal value
+             * This is the basics, and apart from this, there is some randomness in the exact turn count, but I don't know how much
+             * There is surprisingly little information findable online about this policy, and the civ 5 source files are
+             *  also quite though to search through, so this might all be incorrect.
+             * For now this mechanic seems decent enough that this is fine.
+             * Note that the way this is implemented now, this unique does NOT stack
+             * I could parametrize the [Allied], but eh.
+             */
             UniqueType.CityStateCanGiftGreatPeople -> {
                 civInfo.addFlag(
                     CivFlags.CityStateGreatPersonGift.name,
@@ -376,21 +423,6 @@ object UniqueTriggerActivation {
                 }
                 return true
             }
-            // The mechanics for granting great people are wonky, but basically the following happens:
-            // Based on the game speed, a timer with some amount of turns is set, 40 on regular speed
-            // Every turn, 1 is subtracted from this timer, as long as you have at least 1 city state ally
-            // So no, the number of city-state allies does not matter for this. You have a global timer for all of them combined.
-            // If the timer reaches the amount of city-state allies you have (or 10, whichever is lower), it is reset.
-            // You will then receive a random great person from a random city-state you are allied to
-            // The very first time after acquiring this policy, the timer is set to half of its normal value
-            // This is the basics, and apart from this, there is some randomness in the exact turn count, but I don't know how much
-
-            // There is surprisingly little information findable online about this policy, and the civ 5 source files are
-            // also quite though to search through, so this might all be incorrect.
-            // For now this mechanic seems decent enough that this is fine.
-
-            // Note that the way this is implemented now, this unique does NOT stack
-            // I could parametrize the [Allied], but eh.
 
             UniqueType.OneTimeGainStat -> {
                 val stat = Stat.safeValueOf(unique.params[1]) ?: return false
@@ -414,6 +446,7 @@ object UniqueTriggerActivation {
                 civInfo.addNotification(notificationText, LocationAction(tile?.position), NotificationCategory.General, stat.notificationIcon)
                 return true
             }
+
             UniqueType.OneTimeGainStatRange -> {
                 val stat = Stat.safeValueOf(unique.params[2]) ?: return false
 
